# Visualizer UI Documentation

## Get Started

```html
<html>
  <head>
    <link
      href="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/index.css"
      rel="stylesheet"
    />
  </head>
  <body>
    <div class="visualizer" data-role="visualizer" experienceId="<your experience id here>"></div>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer@2.0.64/dist/index.js"></script>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/index.js"></script>
  </body>
</html>
```

### this project is a plugin for the visualizer, see <https://www.npmjs.com/package/@byondrnd/byondxr-web-visualizer> for more information

## Customization, Theming Supported & css variables

It can be given as a configuration linked to the experienceId
Otherwise as a HTML and CSS as in the examples bellow..

To override a css rules add a css file like in the example
<https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/examples/globalVariables.css>

### Changing constant titles labels and icons

pass a stringified object as an attribute into the base div element

#### example

```html
<html>
  <head>
    <link
      href="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/index.css"
      rel="stylesheet"
    />
  </head>
  <body>
    <div
      class="visualizer"
      data-role="visualizer"
      experienceId="<your experience id here>"
      constants='{"menu":{"hotspots":{"label":"Hotspots"}}}'
    ></div>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer@2.0.64/dist/index.js"></script>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/index.js"></script>
  </body>
</html>
```

#### a full Documentation of custom labels titles and icons can be found  under the Constants section
<https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/doc/globals.html#constants>"

#### an example for a constant object can be found at
<https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/build/examples/Constants.json>"

### Client API
It is accessed through an object that is attached to the visualizer container:

```js
const container = document.querySelector('[data-role="visualizer"]')
container.visualizerUI.showAddToCart('sku')
```

Documentation of the methods available on that object:
<https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@2.0.134/doc/classes/ivisualizerui.html>"

## Launcher

```ts
export const launchParamsValidator = jointz
    .object({
        defaultProducts: jointz.object({}).allowUnknownKeys(true),  // <application,sku>
        selector: jointz.string(), // dom selector where visualizer will be deployed
        sceneId: jointz.string(), // the starting scene
        defaultApplication: jointz.string(), // the application in the scene to focus on at the start
        defaultProduct: jointz.or(jointz.string(), jointz.number()),  // sku, assigns product to each application, overrides defaultProducts
        scene_configuration: jointz.string(), // Scene configuration key (like country/language)
        experienceId: jointz.string(), // either hashExperienceId
        hashExperienceId: jointz.string(), // either experienceId
        maxFaceSize: jointz.or(jointz.string(), jointz.number()), // quality of scene in desktop, usually 1024-2048
        maxFaceSizeMobile: jointz.or(jointz.string(), jointz.number()), // quality of scene in mobile, usually 1024-2048
        productsList: jointz.array(jointz.or(jointz.string(), jointz.number())), // optional list of products - only these products of all the catalog products will be used
    })
    .allowUnknownKeys(true)

type TLaunchParams = Infer<typeof launchParamsValidator> & { // documentation of the parameters is in documentation of Visualizer class in the logic side
    favoriteScenes?: Parameters<Visualizer['setFavoriteScenes']>[0] // array of favorite scenes that was sent previously by Visualizer
    favoriteProducts?: Parameters<Visualizer['setFavoriteProducts']>[0] // array of favorite products that was sent previously by Visualizer or array of product skus and applications
}

type TVisualizerContainer: Element
window.launchVisualizer(params: TLaunchParams): Promise<TVisualizerContainer>
```

example:

```html
        <button
            onClick={() => {
                window.launchVisualizer({
                    experienceId: 'G2GcP2',
                    defaultProducts: { Countertop: '1200302000' },
                    defaultProduct: '1200302000',
                    productsList: ['1200302000', '334442000']
                    sceneId: '6',
                    scene_configuration: 'US-EN',
                }).then((visualizerContainer)=>{
                    // Here the visualizer is loaded and you can do with it whatever you need such as:
                    visualizerContainer.visualizerUI.showAddToCart('sku')
                    visualizerContainer.visualizer.setFavoriteProducts([ {product: {application: 'Backsplash', sku: '1040502005'}} ])
                })
            }}
        >
            Launch
        </button>
```

---
